# Activation Functions

::::{grid} 1 2 2 3
:margin: 4 4 0 0
:gutter: 1

:::{grid-item-card} {octicon}`table` Sigmoid
:link: sigmoid
:link-type: doc

A logistic sigmoid function, mapping values from $\mathbb{R}$ to $(0, 1)$.
:::
::::

```{toctree}
:hidden:
:maxdepth: 3

Sigmoid <sigmoid.md>
```